netapp_ontap.models.active_directory_discovered_servers API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.active_directory_discovered_servers`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ActiveDirectoryDiscoveredServersSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ActiveDirectoryDiscoveredServers object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `domain: str GET POST PATCH`

    The Active Directory domain that the discovered server is a member of.

    Example: server1.com

  `node: Node GET POST PATCH`

    The node field of the active_directory_discovered_servers.

  `preference: str GET POST PATCH`

    The preference level of the server that was discovered.

    Valid choices:

    - unknown
    - preferred
    - favored
    - adequate
  `server: ActiveDirectoryDiscoveredServer GET POST PATCH`

    The server field of the active_directory_discovered_servers.

  `state: str GET POST PATCH`

    The status of the connection to the server that was discovered.

    Valid choices:

    - ok
    - unavailable
    - slow
    - expired
    - undetermined
    - unreachable